@@ -35,13 +35,12 @@ Q_PROPERTY(int startElements MEMBER m_startElements)
 public:
     explicit DummyBackend(QObject* parent = nullptr);
 
-    void setMetaData(const QString& path) override;
-    AbstractResource* resourceByPackageName(const QString& name) const override;
     int updatesCount() const override;
     AbstractBackendUpdater* backendUpdater() const override;
     AbstractReviewsBackend* reviewsBackend() const override;
-    QList<AbstractResource*> searchPackageName(const QString& searchText) override;
-    QVector<AbstractResource*> allResources() const override;
+    ResultsStream* search(const AbstractResourcesBackend::Filters & search) override;
+    ResultsStream * findResourceByPackageName(const QUrl& search) override;
+    QHash<QString, DummyResource*> resources() const { return m_resources; }
     bool isValid() const override { return true; } // No external file dependencies that could cause runtime errors
     QList<QAction*> messageActions() const override { return m_messageActions; }
 
@@ -49,6 +48,7 @@ public:
     void installApplication(AbstractResource* app, const AddonList& addons) override;
     void removeApplication(AbstractResource* app) override;
     bool isFetching() const override { return m_fetching; }
+    AbstractResource * resourceForFile(const QUrl & ) override;
 
 public Q_SLOTS:
     void checkForUpdates();
