@@ -27,6 +27,7 @@
 #include <QScopedPointer>
 #include <QVector>
 #include <QCollatorSortKey>
+#include <QJsonObject>
 
 #include "discovercommon_export.h"
 #include "PackageState.h"
@@ -154,8 +155,8 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
 
         virtual QString appstreamId() const;
 
-        void addMetadata(const QString &key, const QVariant &value);
-        QVariant getMetadata(const QString &key);
+        void addMetadata(const QString &key, const QJsonValue &value);
+        QJsonValue getMetadata(const QString &key);
 
         bool canUpgrade();
         bool isInstalled();
@@ -207,7 +208,7 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
 
 //         TODO: make it std::optional or make QCollatorSortKey()
         QScopedPointer<QCollatorSortKey> m_collatorKey;
-        QVariantMap m_metadata;
+        QJsonObject m_metadata;
 };
 
 Q_DECLARE_METATYPE(QVector<AbstractResource*>)
